@@ -14,12 +14,12 @@ autodoc_default_flags = ["members", "special-members"]
 # under RTD.
 target = join(dirname(__file__), "..", "www", "_build")
 if on_rtd:
-    target = "http://www.fabfile.org/"
+    target = "https://www.fabfile.org/"
 www = (target, None)
 # Intersphinx connection to www site
 intersphinx_mapping.update({"www": www})
 
 # Sister-site links to WWW
 html_theme_options["extra_nav_links"] = {
-    "Main website": "http://www.fabfile.org"
+    "Main website": "https://www.fabfile.org"
 }
